@@ -1,5 +1,5 @@
 package DBIx::Perlish::Parse;
-# $Id: Parse.pm,v 1.80 2008/01/15 15:37:46 tobez Exp $
+# $Id: Parse.pm,v 1.82 2008/02/07 11:32:09 tobez Exp $
 use 5.008;
 use warnings;
 use strict;
@@ -236,6 +236,10 @@ sub get_value
 		}
 		bailout $S, "unable to extract a value from a hash(ref)" unless $vv;
 		$val = $vv->{$key};
+	} elsif (is_svop($op, "gvsv") || is_padop($op, "gvsv")) {
+		my $gv = get_gv($S, $op);
+		bailout $S, "unable to get GV from \"", $op->name, "\"" unless $gv;
+		$val = ${$gv->SV->object_2svref};
 	} else {
 		return () if $p{soft};
 		bailout $S, "cannot parse \"", $op->name, "\" op as a value or value reference";
@@ -589,9 +593,9 @@ sub get_gv
 	my ($S, $op) = @_;
 
 	my ($gv_on_pad, $gv_idx);
-	if (is_svop($op, "gv")) {
+	if (is_svop($op, "gv") || is_svop($op, "gvsv")) {
 		$gv_idx = $op->targ;
-	} elsif (is_padop($op, "gv")) {
+	} elsif (is_padop($op, "gv") || is_padop($op, "gvsv")) {
 		$gv_idx = $op->padix;
 		$gv_on_pad = 1;
 	} else {
